@@ -42,7 +42,9 @@ class NacosClient:
             content_md5 = ''
         else:
             content_md5 = self._get_md5(content)
-        para = f"{data_id}{char_2}{group}{char_2}{content_md5}{char_1}"
+        para = "{data_id}{char_2}{group}{char_2}{content_md5}{char_1}".format(
+            data_id=data_id, char_2=char_2, group=group,
+            content_md5=content_md5, char_1=char_1)
         params = {"Listening-Configs": para}
         headers = {"Long-Pulling-Timeout": "30000"}
         res = requests.post(url, params=params, headers=headers)
